%define major 3
%define libname         %mklibname hepmc %{major}
%define develname       %mklibname hepmc -d

Name:           hepmc
Version:        3.2.1
Release:        %mkrel 1
Summary:        An event record for High Energy Physics Monte Carlo Generators in C++
License:        GPL-2.0-only
Group:          Sciences/Physics
URL:            http://hepmc.web.cern.ch/hepmc/
Source:         http://hepmc.web.cern.ch/hepmc/releases/HepMC3-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  ghostscript-fonts
BuildRequires:  graphviz
BuildRequires:  python3-devel

#https://aur.archlinux.org/packages/hepmc3/
#https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=952628
Patch0: hepmc3-gcc93.patch

%description
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

%package -n %{libname}
Summary:        An event record for High Energy Physics Monte Carlo Generators
Group:          Sciences/Physics
Provides:       hepmc = %{version}-%{release}

%description -n %{libname}
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported: the number of entries
is unlimited, spin density matrices can be stored with each vertex,
flow patterns (such as color) can be stored and traced, integers
representing random number generator states can be stored, and an
arbitrary number of event weights can be included. Particles and
vertices are kept separate in a graph structure, physically similar to
a physics event. The added information supports the modularisation of
event generators. Event information is accessed by means of iterators
supplied with the package.

%package -n python%{python3_pkgversion}-%{name}
Summary:	HepMC3 Python 3 bindings
Requires:	%{libname} = %{version}-%{release}

%description -n python%{python3_pkgversion}-%{name}
This package provides the Python 3 bindings for HepMC3.
 

%package doc
Summary:	HepMC Documentation
Group:		Documentation
BuildArch:	noarch

%description doc
This package provides documentation for HepMC.

%package -n %{develname}
Summary:        Header files for HepMC
Group:          Sciences/Physics
Requires:       %{libname} = %{version}-%{release}
Provides:       hepmc-devel = %{version}-%{release}

%description -n %{develname}
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the source and header files required for
developing with HepMC.

%prep
%autosetup -n HepMC3-%{version} -p1

%build
%cmake -DHEPMC3_ENABLE_ROOTIO:BOOL=OFF \
       -DCONFIG_INSTALL_DIR:PATH=%{_libdir}/HepMC/ \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DHEPMC3_BUILD_EXAMPLES:BOOL=OFF \
       -DHEPMC3_PYTHON_VERSIONS=%python3_version 

%cmake_build
pushd doc/doxygen
doxygen
popd

%install
%cmake_install
# REMOVE STATIC LIBRARIES
rm -f %{buildroot}%{_libdir}/*.a

# Weird duplicated installation dir
rm -fr %{buildroot}%{_builddir}

chmod +x %{buildroot}%{_bindir}/HepMC3-config

#Install examples manually so that fdupes can be run on them
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -pr examples %{buildroot}%{_docdir}/%{name}/
cp -pr doc/doxygen/html %{buildroot}%{_docdir}/%{name}/

%files -n %{libname}
%{_libdir}/libHepMC3.so.*
%{_libdir}/libHepMC3search.so.*

%files -n %{develname}
%doc README* ChangeLog DESIGN
%{_bindir}/HepMC3-config
%{_libdir}/libHepMC3.so
%{_libdir}/libHepMC3search.so
%{_includedir}/HepMC3/
%{_datadir}/HepMC3/

%files doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/examples
%doc %{_docdir}/%{name}/html
	
%files -n python%{python3_pkgversion}-%{name}
%dir %{python3_sitearch}/pyHepMC3
%{python3_sitearch}/pyHepMC3/__init__.py
%{python3_sitearch}/pyHepMC3/__pycache__
%{python3_sitearch}/pyHepMC3/pyHepMC3.so
%{python3_sitearch}/pyHepMC3-*.egg-info
%{python3_sitearch}/pyHepMC3.search-*.egg-info
%{python3_sitearch}/pyHepMC3/search/__init__.py
%{python3_sitearch}/pyHepMC3/search/__pycache__
%{python3_sitearch}/pyHepMC3/search/pyHepMC3search.so


%changelog
* Sat Apr 25 2020 joequant <joequant> 3.2.1-1.mga8
+ Revision: 1572084
- imported package hepmc

